permission Package
==================

:mod:`permission` Package
-------------------------

.. automodule:: permission
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backends` Module
----------------------

.. automodule:: permission.backends
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`conf` Module
------------------

.. automodule:: permission.conf
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`handlers` Module
----------------------

.. automodule:: permission.handlers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`models` Module
--------------------

.. automodule:: permission.models
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    permission.decorators
    permission.logics
    permission.templatetags
    permission.tests
    permission.utils

